@@ -1,11 +1,10 @@
-from __future__ import absolute_import
-# Copyright (c) 2010-2015 openpyxl
+# Copyright (c) 2010-2022 openpyxl
 
 from openpyxl.compat import safe_string
 
 from openpyxl.descriptors import Bool, MinMax, Min, Alias, NoneSet
+from openpyxl.descriptors.serialisable import Serialisable
 
-from .hashable import HashableObject
 
 horizontal_alignments = (
     "general", "left", "center", "right", "fill", "justify", "centerContinuous",
@@ -14,7 +13,7 @@ vertical_aligments = (
     "top", "center", "bottom", "justify", "distributed",
 )
 
-class Alignment(HashableObject):
+class Alignment(Serialisable):
     """Alignment options for use in styles."""
 
     tagname = "alignment"
@@ -38,15 +37,15 @@ class Alignment(HashableObject):
     wrap_text = Alias('wrapText')
     shrinkToFit = Bool(allow_none=True)
     shrink_to_fit = Alias('shrinkToFit')
-    indent = Min(min=0)
-    relativeIndent = Min(min=0)
+    indent = MinMax(min=0, max=255)
+    relativeIndent = MinMax(min=-255, max=255)
     justifyLastLine = Bool(allow_none=True)
     readingOrder = Min(min=0)
 
     def __init__(self, horizontal=None, vertical=None,
                  textRotation=0, wrapText=None, shrinkToFit=None, indent=0, relativeIndent=0,
                  justifyLastLine=None, readingOrder=0, text_rotation=None,
-                 wrap_text=None, shrink_to_fit=None) :
+                 wrap_text=None, shrink_to_fit=None, mergeCell=None):
         self.horizontal = horizontal
         self.vertical = vertical
         self.indent = indent
@@ -63,6 +62,7 @@ class Alignment(HashableObject):
         if shrink_to_fit is not None:
             shrinkToFit = shrink_to_fit
         self.shrinkToFit = shrinkToFit
+        # mergeCell is vestigial
 
 
     def __iter__(self):
