@@ -1,14 +1,11 @@
-from __future__ import absolute_import
-# Copyright (c) 2010-2018 openpyxl
+# Copyright (c) 2010-2022 openpyxl
 
 from openpyxl.descriptors.serialisable import Serialisable
 from openpyxl.descriptors import (
     Float,
     Bool,
     Integer,
-    String,
     NoneSet,
-    Alias,
     )
 from openpyxl.descriptors.excel import UniversalMeasure, Relation
 
@@ -82,6 +79,12 @@ class PrintPageSetup(Serialisable):
         self.id = id
 
 
+    def __bool__(self):
+        return bool(dict(self))
+
+
+
+
     @property
     def sheet_properties(self):
         """
@@ -140,6 +143,10 @@ class PrintOptions(Serialisable):
         self.gridLinesSet = gridLinesSet
 
 
+    def __bool__(self):
+        return bool(dict(self))
+
+
 class PageMargins(Serialisable):
     """
     Information about page margins for view/print layouts.
